==> e2e-cypress-dsl-10.3.6.zip: dsl/pages/profile-page.js <==
export default class ProfilePage {
    constructor() {
        cy.get('#profileForm').should('be.visible');
    }

    expectEmailDefined(email) {
        cy.get('#email').should('have.value', email);
        return this;
    }

    expectFullNameDefined(fullName) {
        cy.get('#full-name').should('have.value', fullName);
        return this;
    }

    expectNoEmailDefined() {
        this.expectEmailDefined('');
        return this;
    }

    expectNoFullNameDefined() {
        this.expectFullNameDefined('');
        return this;
    }

    expectPasswordNotToBe(password) {
        cy.get('input[data-test="password-input"]').should('not.have.value', password);
        return this;
    }

    expectDateFormatToBe(dateFormat) {
        cy.get('select[ng-model="$ctrl.profile.dateFormat"]').should('have.value', dateFormat);
        return this;
    }

    expectTimeFormatToBe(timeFormat) {
        cy.get('select[ng-model="$ctrl.profile.timeFormat"]').should('have.value', timeFormat);
        return this;
    }

    expectFirstDayOfWeekToBe(firstDayOfWeek) {
        cy.get('select[ng-model="$ctrl.profile.firstDayOfWeek"]').should('have.value', firstDayOfWeek);
        return this;
    }

    save() {
        let lastSaved;
        cy.then(() => {
            const e = Cypress.$('.last-saved');
            lastSaved = e.length ? e.text() : '';
            if (lastSaved) {
                return new Promise((res) => setTimeout(res, 1200)); // to make sure we do not save same second
            }
        });
        cy.get('#profile .save:enabled').click();
        cy.get('.last-saved').should('be.visible');
        cy.waitWithoutFailing(() => expect(Cypress.$('.last-saved').text()).to.not.equal(lastSaved));
        // element(By.$('#profile .save:enabled')).click();
        // Browser.waitFor('.last-saved');
        return this;
    }


    setEmail(email) {
        cy.get('#email').type(email);
        return this.save();
    }

    setFullName(fullName) {
        cy.get('#full-name').type(fullName);
        return this.save();
    }

    setPassword(previousPassword, password) {
        cy.get('#previousPassword').type(previousPassword);
        cy.get('input[data-test="password-input"]').type(password);
        cy.get('#passwordConfirmation').type(password);
        cy.get('#profile .save:enabled').click();
        return this;
    }

    setDateFormat(dateFormat) {
        cy.get(`.form-group:contains('Date format') select`).select(dateFormat);
        return this.save();
    }

    setTimeFormat(timeFormat) {
        cy.get(`.form-group:contains('Time format') select`).select(timeFormat);
        return this.save();
    }

    setFirstDayOfWeek(firstDayOfWeek) {
        cy.get(`.form-group:contains('First day of week') select`).select(firstDayOfWeek);
        return this.save();
    }

    refresh() {
        cy.reload();
        return new ProfilePage();
    }
}

==> e2e-cypress-dsl-22.2.2.zip: dsl/pages/profile-page.js <==
export default class ProfilePage {
    constructor() {
        cy.get('#profileForm').should('be.visible');
    }

    expectEmailDefined(email) {
        cy.get('#email').should('have.value', email);
        return this;
    }

    expectFullNameDefined(fullName) {
        cy.get('#full-name').should('have.value', fullName);
        return this;
    }

    expectNoEmailDefined() {
        this.expectEmailDefined('');
        return this;
    }

    expectNoFullNameDefined() {
        this.expectFullNameDefined('');
        return this;
    }

    expectPasswordNotToBe(password) {
        cy.get('input[data-test="password-input"]').should('not.have.value', password);
        return this;
    }

    expectDateFormatToBe(dateFormat) {
        cy.get('select[ng-model="$ctrl.profile.dateFormat"]').should('have.value', dateFormat);
        return this;
    }

    expectTimeFormatToBe(timeFormat) {
        cy.get('select[ng-model="$ctrl.profile.timeFormat"]').should('have.value', timeFormat);
        return this;
    }

    expectFirstDayOfWeekToBe(firstDayOfWeek) {
        cy.get('select[ng-model="$ctrl.profile.firstDayOfWeek"]').should('have.value', firstDayOfWeek);
        return this;
    }

    save() {
        let lastSaved;
        cy.then(() => {
            const e = Cypress.$('.saved-text');
            lastSaved = e.length ? e.text() : '';
            if (lastSaved) {
                return new Promise((res) => setTimeout(res, 1200)); // to make sure we do not save same second
            }
        });
        cy.get('action-toolbar button:contains("Save"):enabled').click();
        cy.get('.saved-text').should('be.visible');
        cy.waitWithoutFailing(() => expect(Cypress.$('.last-saved').text()).to.not.equal(lastSaved));
        // element(By.$('#profile .save:enabled')).click();
        // Browser.waitFor('.last-saved');
        return this;
    }

    setEmail(email) {
        cy.get('#email').type(email);
        return this.save();
    }

    setFullName(fullName) {
        cy.get('#full-name').type(fullName);
        return this.save();
    }

    setPassword(previousPassword, password) {
        cy.get('#previousPassword').type(previousPassword);
        cy.get('input[data-test="password-input"]').type(password);
        cy.get('#passwordConfirmation').type(password);
        cy.get('action-toolbar button:contains("Save"):enabled').click();
        return this;
    }

    setDateFormat(dateFormat) {
        cy.get(`.form-group:contains('Date format') select`).select(dateFormat);
        return this.save();
    }

    setTimeFormat(timeFormat) {
        cy.get(`.form-group:contains('Time format') select`).select(timeFormat);
        return this.save();
    }

    setFirstDayOfWeek(firstDayOfWeek) {
        cy.get(`.form-group:contains('First day of week') select`).select(firstDayOfWeek);
        return this.save();
    }

    refresh() {
        cy.reload();
        return new ProfilePage();
    }
}
